/* $Workfile: OtxWrapper.c $   $Revision: 2 $    $Modtime: 8/24/04 4:42p $ */
/*******************************************************************************

  Copyright (C) 1998 Odin TeleSystems Inc., All Rights Reserved

  @doc internal

  OtxWrapper.c

  A simple demonstration wrapper around the OTX SDK library.

  The function in this module wrap the standard OTX API calls around
  traditional data types.  This is useful when interfacing from a source
  that is unable to supply data to the API library as it is expecting (a
  good example is the lack of structure support from a 4GL tool).

*******************************************************************************/

// standard platform includes
#include <windows.h>

// OTX API SDK include files
#include "OtxErr.h"
#include "OtxGeneric.h"
#include "OtxData.h"

// OTX API SDK interface include files
#include "OtxDrv.h"
#include "OtxT1E1.h"

// our include file
#include "OtxWrapper.h"


HINSTANCE g_hInstance;      // global dll instance handle

/*******************************************************************************
*******************************************************************************/
BOOL APIENTRY DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
{
  switch (fdwReason) {
    case DLL_PROCESS_ATTACH:
      g_hInstance = hinstDLL;         // save the instance handle
      break;
    case DLL_THREAD_ATTACH:
    case DLL_THREAD_DETACH:
    case DLL_PROCESS_DETACH:
      break;
  }

  return TRUE;
}


/*******************************************************************************
*******************************************************************************/

int _stdcall WrapOtxDrvConnectLib(void)
{
  return (int) OtxDrvConnectLib();
}

int _stdcall WrapOtxDrvReleaseLib(void)
{
  return (int) OtxDrvReleaseLib();
}

int _stdcall WrapOtxDrvIteratorBegin(void *pItr)
{
  return (int) OtxDrvIteratorBegin((OTX_ITERATOR *) pItr);
}

int _stdcall WrapOtxDrvIteratorEnd(int *pItr)
{
  return (int) OtxDrvIsIteratorEnd((OTX_ITERATOR *) pItr);
}

int _stdcall WrapOtxDrvGetAttributeValueUint32(unsigned int hDevice, unsigned int nAttribId, unsigned int *pAttribValue)
{
  return (int) OtxDrvGetAttributeValueUint32(hDevice, nAttribId, pAttribValue);
}

int _stdcall GetOtxDrvGetAttributeValueUint32(unsigned int hDevice, unsigned int nAttribId)
{
  unsigned int AttribValue;

  OtxDrvGetAttributeValueUint32(hDevice, nAttribId, &AttribValue);
  return AttribValue;
}

int _stdcall WrapOtxDrvEnumDeviceType(unsigned int hDevice, unsigned int *pItr, unsigned int *peDeviceType)
{
  return (int) OtxDrvEnumDeviceType(hDevice, pItr, peDeviceType);
}

int _stdcall WrapOtxDrvEnumDevice(unsigned int hDevice, unsigned int eDeviceType, unsigned int *pItr, unsigned int *phChildDevice)
{
  return (int) OtxDrvEnumDevice(hDevice, eDeviceType, (OTX_ITERATOR *) pItr, phChildDevice);
}

int _stdcall WrapOtxDrvCreateEvent(unsigned int *phEvent)
{
  return (int) OtxDrvCreateEvent((OTX_EVENT *) phEvent);
}

int _stdcall WrapOtxDrvCreateEventQueue(unsigned int nSize, unsigned int hEvent, unsigned int *phEventQueue) 
{
  return (int) OtxDrvCreateEventQueue(nSize, (OTX_EVENT *) hEvent, phEventQueue);
}

int _stdcall WrapOtxDrvEnable(unsigned int hObject, unsigned int nTaskRef, unsigned int nWaitMaxMs)
{
  return (int) OtxDrvEnable(hObject, nTaskRef, nWaitMaxMs);
}

int _stdcall WrapOtxDrvOpenPhysicalDevice(unsigned int hHostDevice, unsigned int eDevType, unsigned int nDevice, unsigned int nEventSourceId, unsigned int hEventQueue, unsigned int *phPhysDevice) 
{
  return (int) OtxDrvOpenPhysicalDevice(hHostDevice, eDevType, nDevice, nEventSourceId, hEventQueue, phPhysDevice);
}

int _stdcall WrapOtxDrvClose(unsigned int hDevice) 
{
  return (int) OtxDrvClose(hDevice);
}

/*******************************************************************************
*******************************************************************************/


static OtxE1ConfigOptionsS sE1Configuration;
static OTX_RESULT res_GetE1Configuration = OTX_E_UNEXPECTED;


/*******************************************************************************
  wrapper for

  OTX_RESULT OtxE1SetConfiguration(
    IN OTX_HANDLE hLineDevice,
    IN OtxE1ConfigOptionsS *pE1ConfigOptions
  );

*******************************************************************************/
int _stdcall WrapOtxE1SetConfiguration(
  unsigned int     hLineDevice,        // Handle to the T1/E1 Transceiver Device
  unsigned int     eTxLineCode,        // Line Coding in Transmit Direction
  unsigned int     eRxLineCode,        // Line Coding in Receive Direction
  unsigned int     eTxFrameFormat,     // Frame Format in Transmit Direction
  unsigned int     eRxFrameFormat,     // Frame Format in Receive Direction
  unsigned int     eAisDetection,      // Alarm Indication Signal (AIS) Detect mode
  unsigned char    bfSiBits,           // E-bit (spare bits for international use) Due to signalling requirements
                                       // the E-bits (SiBits) of frame 13 and frame 15 of the CRC multiframe can be
                                       // used to indicate received errored submultiframes. E-bit of frame 15 is the least
                                       // significant bit (bit 0) of this field. E-bit of frame 13 is bit 1 of this field.
                                       // To set the either E-bit in the in the multiframe
                                       // the corresponding bit position in this field should be turned on.
                                       // E-bit Frame 13, E-bit Frame 15: 00, 01, 10, 11.
                                       // E.g. to set both E-bits (frame 13 and frame 15) set this field to 0x03.
  unsigned char    bfSaBits,           // Set the Sa bits (spare bits for national use) transmitted in bit
                                       // positions 4-8 of time-slot 0 of every other (odd) frame. Use bit pattern
                                       // marking the corresponding bit position '1' the bit should be turned on.
                                       // Sa4, Sa5, Sa6, Sa7, Sa8: 00000, 00001, ..., 11111
                                       // <nl> For all Sa bits on nSaBits = 0x1F
  unsigned char    bExtendedHDB3errorDetect,  // Selects the error detection mode. When turned off (OTX_FALSE),
                                       // only double violations are detected. When turned on (OTX_TRUE), 0000 strings
                                       // are detected as code violations as well.
  unsigned char    bAutoRegainMultiframe,// When enabled (OTX_TRUE), the receiver will search a new basic-
                                       // and multiframing if more than 914 CRC errors have been detected in a
                                       // time interval of one second.
  unsigned char    bAutoResync,        // If OTX_TRUE, the Framer will automatically re-synchronize after
                                       // loss of synchronization. If OTX_FALSE the Framer will not synchronize
                                       // automatically but a re-synchronization procedure must be specifically
                                       // initiated by the software.
  unsigned char    bAutoCrcBitInversion, // If OTX_TRUE, all CRC bits of one outgoing sub-multiframe are
                                       // inverted in case a CRC error is flagged for the previous received 
                                       // sub-multiframe.
  unsigned char    bAutoRemoteAlarm,   // If OTX_TRUE, a Remote Alarm (Yellow Alarm) will be sent automatically
                                       // in the outgoing data stream when the receiver is out of synchronization.
                                       // The alarm will also be automatically removed when the receiver returns to
                                       // the synchronized state.
  unsigned char    nLosSensitivity,    // Sets the sensitivity level for the Loss Of Signal (LOS) detection.
                                       // A LOS alarm will be generated if the incoming data stream has no
                                       // transitions during programmable number (N) of consecutive pulse periods.
                                       // The number given as the LOS Sensitivity value will be multiplied by 16 to
                                       // arrive to the pulse count number N. The time for detecting LOS will be
                                       // 16 x LOS Sensitivity x Pulse Length (488ns).
                                       // The maximum time is 16 x 256 x 488ns = 2ms
                                       // <nl> Possible Values: 1-256
                                       // <nl> Example/Default Value:
                                       // LOS Sensitivity  =  128     (16 x 128 x 488ns = 1ms)
  unsigned char    nLosRecovery,       // Sets the sensitivity level for the Loss Of Signal (LOS) recovery.
                                       // A LOS alarm will be cleared if in the incoming data a number of Pulses (N)
                                       // occur during the time period set with the LOS Recovery parameter. The time
                                       // interval starts with the first detected pulse transition and a pulse
                                       // count is incremented with every received pulse. If the pulse number is
                                       // greater than the number N set with this parameter, the LOS alarm will be cleared.
                                       // <nl> Possible Values: 1-256
  unsigned short   nLineLength,        // Specify the length of the T1 line cable in meters. This information
                                       // is used by the T1 transceivers to adjust the transmit pulse masks according
                                       // to the line length.
                                       // <nl> Possible Values: 0-65535
  unsigned char    bHighTxPower,       // When OTX_TRUE the pulses on the line interface will be sent with
                                       // high power. If OTX_FALSE the pulses will be sent with low power.
  unsigned char    bReceiveEqualizer   // The Receive Equalizer can be used match the 18dB ITU-T I.431
                                       // requirement. When the Equalizer is turned off (OTX_FALSE), the Receiver is -10dB (short haul), when
                                       // turned on (OTX_TRUE), the Receiver is -36dB (long haul).
)
{
  OtxE1ConfigOptionsS   sIn;
  OTX_RESULT            result;

  memset(&sIn, 0, sizeof(sIn));
  sIn.eTxLineCode                 = (OtxE1LineCodeE)      eTxLineCode;
  sIn.eRxLineCode                 = (OtxE1LineCodeE)      eRxLineCode;
  sIn.eTxFrameFormat              = (OtxE1FrameFormatE)   eTxFrameFormat;
  sIn.eRxFrameFormat              = (OtxE1FrameFormatE)   eRxFrameFormat;
  sIn.eAisDetection               = (OtxE1AisDetectModeE) eAisDetection;
  sIn.bfSiBits                    = (OTX_UINT8)           bfSiBits;
  sIn.bfSaBits                    = (OTX_UINT8)           bfSaBits;
  sIn.bExtendedHDB3errorDetect    = (OTX_BOOL)            bExtendedHDB3errorDetect;
  sIn.bAutoRegainMultiframe       = (OTX_BOOL)            bAutoRegainMultiframe;
  sIn.bAutoResync                 = (OTX_BOOL)            bAutoResync;
  sIn.bAutoCrcBitInversion        = (OTX_BOOL)            bAutoCrcBitInversion;
  sIn.bAutoRemoteAlarm            = (OTX_BOOL)            bAutoRemoteAlarm;
  sIn.nLosSensitivity             = (OTX_UINT8)           nLosSensitivity;
  sIn.nLosRecovery                = (OTX_UINT8)           nLosRecovery;
  sIn.nLineLength                 = (OTX_UINT16)          nLineLength;
  sIn.bHighTxPower                = (OTX_BOOL)            bHighTxPower;
  sIn.bReceiveEqualizer           = (OTX_BOOL)            bReceiveEqualizer;

  result = OtxE1SetConfiguration(hLineDevice, &sIn);

  return (int) result;
}


/*******************************************************************************
*******************************************************************************/


/*******************************************************************************
  wrapper for

  OTX_RESULT OtxE1GetConfiguration(
    IN  OTX_HANDLE hLineDevice,
    OUT OtxE1ConfigOptionsS *pE1ConfigOptions
  );

*******************************************************************************/
int _stdcall WrapOtxE1GetConfiguration(
  unsigned int    hLineDevice,        // Handle to the T1/E1 Transceiver Device
  unsigned int *  eTxLineCode,        // Line CodOUTg OUT Transmit Direction
  unsigned int *  eRxLineCode,        // Line CodOUTg OUT Receive Direction
  unsigned int *  eTxFrameFormat,     // Frame Format OUT Transmit Direction
  unsigned int *  eRxFrameFormat,     // Frame Format OUT Receive Direction
  unsigned int *  eAisDetection,      // Alarm OUTdication Signal (AIS) Detect mode
  unsigned char * bfSiBits,           // E-bit (spare bits for OUTternational use) Due to signalLineg requirements
                                      // the E-bits (SiBits) of frame 13 and frame 15 of the CRC multiframe can be
                                      // used to OUTdicate received errored submultiframes. E-bit of frame 15 is the least
                                      // significant bit (bit 0) of this field. E-bit of frame 13 is bit 1 of this field.
                                      // To set the either E-bit OUT the OUT the multiframe
                                      // the correspondOUTg bit position OUT this field should be turned on.
                                      // E-bit Frame 13, E-bit Frame 15: 00, 01, 10, 11.
                                      // E.g. to set both E-bits (frame 13 and frame 15) set this field to 0x03.
  unsigned char *  bfSaBits,          // Set the Sa bits (spare bits for national use) transmitted OUT bit
                                      // positions 4-8 of time-slot 0 of every other (odd) frame. Use bit pattern
                                      // markOUTg the correspondOUTg bit position '1' the bit should be turned on.
                                      // Sa4, Sa5, Sa6, Sa7, Sa8: 00000, 00001, ..., 11111
                                      // <nl> For all Sa bits on nSaBits = 0x1F
  unsigned char *  bExtendedHDB3errorDetect,  // Selects the error detection mode. When turned off (OTX_FALSE),
                                      // only double violations are detected. When turned on (OTX_TRUE), 0000 strOUTgs
                                      // are detected as code violations as well.
  unsigned char *  bAutoRegainMultiframe,// When enabled (OTX_TRUE), the receiver will search a new basic-
                                      // and multiframOUTg if more than 914 CRC errors have been detected OUT a
                                      // time OUTterval of one second.
  unsigned char *  bAutoResync,       // If OTX_TRUE, the Framer will automatically re-synchronize after
                                      // loss of synchronization. If OTX_FALSE the Framer will not synchronize
                                      // automatically but a re-synchronization procedure must be specifically
                                      // OUTitiated by the software.
  unsigned char *  bAutoCrcBitInversion, // If OTX_TRUE, all CRC bits of one outgoOUTg sub-multiframe are
                                      // OUTverted OUT case a CRC error is flagged for the previous received 
                                      // sub-multiframe.
  unsigned char *  bAutoRemoteAlarm,  // If OTX_TRUE, a Remote Alarm (Yellow Alarm) will be sent automatically
                                      // OUT the outgoOUTg data stream when the receiver is out of synchronization.
                                      // The alarm will also be automatically removed when the receiver returns to
                                      // the synchronized state.
  unsigned char *  nLosSensitivity,   // Sets the sensitivity level for the Loss Of Signal (LOS) detection.
                                      // A LOS alarm will be generated if the OUTcomOUTg data stream has no
                                      // transitions durOUTg programmable number (N) of consecutive pulse periods.
                                      // The number given as the LOS Sensitivity value will be multiplied by 16 to
                                      // arrive to the pulse count number N. The time for detectOUTg LOS will be
                                      // 16 x LOS Sensitivity x Pulse Length (488ns).
                                      // The maximum time is 16 x 256 x 488ns = 2ms
                                      // <nl> Possible Values: 1-256
                                      // <nl> Example/Default Value:
                                      // LOS Sensitivity  =  128     (16 x 128 x 488ns = 1ms)
  unsigned char *  nLosRecovery,      // Sets the sensitivity level for the Loss Of Signal (LOS) recovery.
                                      // A LOS alarm will be cleared if OUT the OUTcomOUTg data a number of Pulses (N)
                                      // occur durOUTg the time period set with the LOS Recovery parameter. The time
                                      // OUTterval starts with the first detected pulse transition and a pulse
                                      // count is OUTcremented with every received pulse. If the pulse number is
                                      // greater than the number N set with this parameter, the LOS alarm will be cleared.
                                      // <nl> Possible Values: 1-256
  unsigned short * nLineLength,       // Specify the length of the T1 Line cable OUT meters. This OUTformation
                                      // is used by the T1 transceivers to adjust the transmit pulse masks accordOUTg
                                      // to the Line length.
                                      // <nl> Possible Values: 0-65535
  unsigned char *  bHighTxPower,      // When OTX_TRUE the pulses on the Line OUTterface will be sent with
                                      // high power. If OTX_FALSE the pulses will be sent with low power.
  unsigned char *  bReceiveEqualizer  // The Receive Equalizer can be used match the 18dB ITU-T I.431
                                      // requirement. When the Equalizer is turned off (OTX_FALSE), the Receiver is -10dB (short haul), when
                                      // turned on (OTX_TRUE), the Receiver is -36dB (long haul).
)
{
  OtxE1ConfigOptionsS   sOut;
  OTX_RESULT            result;

  memset(&sOut, 0, sizeof(sOut));
  result = OtxE1GetConfiguration(hLineDevice, &sOut);

  *eTxLineCode                    = (unsigned int)    sOut.eTxLineCode;
  *eRxLineCode                    = (unsigned int)    sOut.eRxLineCode;
  *eTxFrameFormat                 = (unsigned int)    sOut.eTxFrameFormat;
  *eRxFrameFormat                 = (unsigned int)    sOut.eRxFrameFormat;
  *eAisDetection                  = (unsigned int)    sOut.eAisDetection;
  *bfSiBits                       = (unsigned char)   sOut.bfSiBits;
  *bfSaBits                       = (unsigned char)   sOut.bfSaBits;
  *bExtendedHDB3errorDetect       = (unsigned char)   sOut.bExtendedHDB3errorDetect;
  *bAutoRegainMultiframe          = (unsigned char)   sOut.bAutoRegainMultiframe;
  *bAutoResync                    = (unsigned char)   sOut.bAutoResync;
  *bAutoCrcBitInversion           = (unsigned char)   sOut.bAutoCrcBitInversion;
  *bAutoRemoteAlarm               = (unsigned char)   sOut.bAutoRemoteAlarm;
  *nLosSensitivity                = (unsigned char)   sOut.nLosSensitivity;
  *nLosRecovery                   = (unsigned char)   sOut.nLosRecovery;
  *nLineLength                    = (unsigned short)  sOut.nLineLength;
  *bHighTxPower                   = (unsigned char)   sOut.bHighTxPower;
  *bReceiveEqualizer              = (unsigned char)   sOut.bReceiveEqualizer;

  return (int) result;
}


/*******************************************************************************
  routine to get the configuration once, then be able to use the individual
  routines to get the individual members of the configuration.  this allows
  us to get the configuration without having to supply all those parameters
  at once.
*******************************************************************************/
int _stdcall SetE1Configuration(unsigned int hLineDevice)
{
  OTX_RESULT result;

  result = OtxE1SetConfiguration(hLineDevice, &sE1Configuration);
  return (int) result;
}

/*******************************************************************************
  set items in global structure to be applied later when
  SetE1Configuration() is called
*******************************************************************************/
void _stdcall SetE1_eTxLineCode(unsigned int eTxLineCode)
{
  sE1Configuration.eTxLineCode = (OtxE1LineCodeE) eTxLineCode;
}

void _stdcall SetE1_eRxLineCode(unsigned int eRxLineCode)
{
  sE1Configuration.eRxLineCode = (OtxE1LineCodeE) eRxLineCode;
}

void _stdcall SetE1_eTxFrameFormat(unsigned int eTxFrameFormat)
{
  sE1Configuration.eTxFrameFormat = (OtxE1FrameFormatE) eTxFrameFormat;
}

void _stdcall SetE1_eRxFrameFormat(unsigned int eRxFrameFormat)
{
  sE1Configuration.eRxFrameFormat = (OtxE1FrameFormatE) eRxFrameFormat;
}

void _stdcall SetE1_eAisDetection(unsigned int eAisDetection)
{
  sE1Configuration.eAisDetection = (OtxE1AisDetectModeE) eAisDetection;
}

void _stdcall SetE1_bfSiBits(unsigned char bfSiBits)
{
  sE1Configuration.bfSiBits = (OTX_UINT8) bfSiBits;
}

void _stdcall SetE1_bfSaBits(unsigned char bfSaBits)
{
  sE1Configuration.bfSaBits = (OTX_UINT8) bfSaBits;
}

void _stdcall SetE1_bExtendedHDB3errorDetect(unsigned char bExtendedHDB3errorDetect)
{
  sE1Configuration.bExtendedHDB3errorDetect = (OTX_BOOL) bExtendedHDB3errorDetect;
}

void _stdcall SetE1_bAutoRegainMultiframe(unsigned char bAutoRegainMultiframe)
{
  sE1Configuration.bAutoRegainMultiframe = (OTX_BOOL) bAutoRegainMultiframe;
}

void _stdcall SetE1_bAutoResync(unsigned char bAutoResync)
{
  sE1Configuration.bAutoResync = (OTX_BOOL) bAutoResync;
}

void _stdcall SetE1_bAutoCrcBitInversion(unsigned char bAutoCrcBitInversion)
{
  sE1Configuration.bAutoCrcBitInversion = (OTX_BOOL) bAutoCrcBitInversion;
}

void _stdcall SetE1_bAutoRemoteAlarm(unsigned char bAutoRemoteAlarm)
{
  sE1Configuration.bAutoRemoteAlarm = (OTX_BOOL) bAutoRemoteAlarm;
}

void _stdcall SetE1_nLosSensitivity(unsigned char nLosSensitivity)
{
  sE1Configuration.nLosSensitivity = (OTX_UINT8) nLosSensitivity;
}

void _stdcall SetE1_nLosRecovery(unsigned char nLosRecovery)
{
  sE1Configuration.nLosRecovery = (OTX_UINT8) nLosRecovery;
}

void _stdcall SetE1_nLineLength(unsigned short nLineLength)
{
  sE1Configuration.nLineLength = (OTX_UINT16) nLineLength;
}

void _stdcall SetE1_bHighTxPower(unsigned char bHighTxPower)
{
  sE1Configuration.bHighTxPower = (OTX_BOOL) bHighTxPower;
}

void _stdcall SetE1_bReceiveEqualizer(unsigned char bReceiveEqualizer)
{
  sE1Configuration.bReceiveEqualizer = (OTX_BOOL) bReceiveEqualizer;
}


/*******************************************************************************
*******************************************************************************/

/*******************************************************************************
  routine to get the configuration once, then be able to use the individual
  routines to get the individual members of the configuration.  this allows
  us to get the configuration without having to supply all those parameters
  at once.
*******************************************************************************/
int _stdcall GetE1Configuration(unsigned int hLineDevice)
{
  res_GetE1Configuration = OtxE1GetConfiguration(hLineDevice, &sE1Configuration);
  return (int) res_GetE1Configuration;
}

/*******************************************************************************
  return items of E1 configuration when pass data storage buffers
*******************************************************************************/
int _stdcall GetE1_eTxLineCode(unsigned int *eTxLineCode)
{
  *eTxLineCode = (unsigned int) sE1Configuration.eTxLineCode;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_eRxLineCode(unsigned int *eRxLineCode)
{
  *eRxLineCode = (unsigned int) sE1Configuration.eRxLineCode;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_eTxFrameFormat(unsigned int *eTxFrameFormat)
{
  *eTxFrameFormat = (unsigned int) sE1Configuration.eTxFrameFormat;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_eRxFrameFormat(unsigned int *eRxFrameFormat)
{
  *eRxFrameFormat = (unsigned int) sE1Configuration.eRxFrameFormat;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_eAisDetection(unsigned int *eAisDetection)
{
  *eAisDetection = (unsigned int) sE1Configuration.eAisDetection;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bfSiBits(unsigned char *bfSiBits)
{
  *bfSiBits = (unsigned char) sE1Configuration.bfSiBits;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bfSaBits(unsigned char *bfSaBits)
{
  *bfSaBits = (unsigned char) sE1Configuration.bfSaBits;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bExtendedHDB3errorDetect(unsigned char *bExtendedHDB3errorDetect)
{
  *bExtendedHDB3errorDetect = (unsigned char) sE1Configuration.bExtendedHDB3errorDetect;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bAutoRegainMultiframe(unsigned char *bAutoRegainMultiframe)
{
  *bAutoRegainMultiframe = (unsigned char) sE1Configuration.bAutoRegainMultiframe;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bAutoResync(unsigned char *bAutoResync)
{
  *bAutoResync = (unsigned char) sE1Configuration.bAutoResync;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bAutoCrcBitInversion(unsigned char *bAutoCrcBitInversion)
{
  *bAutoCrcBitInversion = (unsigned char) sE1Configuration.bAutoCrcBitInversion;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bAutoRemoteAlarm(unsigned char *bAutoRemoteAlarm)
{
  *bAutoRemoteAlarm = (unsigned char) sE1Configuration.bAutoRemoteAlarm;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_nLosSensitivity(unsigned char *nLosSensitivity)
{
  *nLosSensitivity = (unsigned char) sE1Configuration.nLosSensitivity;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_nLosRecovery(unsigned char *nLosRecovery)
{
  *nLosRecovery = (unsigned char) sE1Configuration.nLosRecovery;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_nLineLength(unsigned short *nLineLength)
{
  *nLineLength = (unsigned short) sE1Configuration.nLineLength;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bHighTxPower(unsigned char *bHighTxPower)
{
  *bHighTxPower = (unsigned char) sE1Configuration.bHighTxPower;
  return (int) res_GetE1Configuration;
}

int _stdcall GetE1_bReceiveEqualizer(unsigned char *bReceiveEqualizer)
{
  *bReceiveEqualizer = (unsigned char) sE1Configuration.bReceiveEqualizer;
  return (int) res_GetE1Configuration;
}


/*******************************************************************************
  return the E1 configuration items the return value

  caution: this could return an incorrect value if GetE1Configuration() was
  never called or it returned an error. Using the functions above
  at least gives a chance to catch this condition, but may not be
  available if pointers to storage cannot be passed as parameters.
*******************************************************************************/

unsigned int _stdcall RetE1_eTxLineCode(void)
{
  return (unsigned int) sE1Configuration.eTxLineCode;
}

unsigned int _stdcall RetE1_eRxLineCode(void)
{
  return (unsigned int) sE1Configuration.eRxLineCode;
}

unsigned int _stdcall RetE1_eTxFrameFormat(void)
{
  return (unsigned int) sE1Configuration.eTxFrameFormat;
}

unsigned int _stdcall RetE1_eRxFrameFormat(void)
{
  return (unsigned int) sE1Configuration.eRxFrameFormat;
}

unsigned int _stdcall RetE1_eAisDetection(void)
{
  return (unsigned int) sE1Configuration.eAisDetection;
}

unsigned char _stdcall RetE1_bfSiBits(void)
{
  return (unsigned char) sE1Configuration.bfSiBits;
}

unsigned char _stdcall RetE1_bfSaBits(void)
{
  return (unsigned char) sE1Configuration.bfSaBits;
}

unsigned char _stdcall RetE1_bExtendedHDB3errorDetect(void)
{
  return (unsigned char) sE1Configuration.bExtendedHDB3errorDetect;
}

unsigned char _stdcall RetE1_bAutoRegainMultiframe(void)
{
  return (unsigned char) sE1Configuration.bAutoRegainMultiframe;
}

unsigned char _stdcall RetE1_bAutoResync(void)
{
  return (unsigned char) sE1Configuration.bAutoResync;
}

unsigned char _stdcall RetE1_bAutoCrcBitInversion(void)
{
  return (unsigned char) sE1Configuration.bAutoCrcBitInversion;
}

unsigned char _stdcall RetE1_bAutoRemoteAlarm(void)
{
  return (unsigned char) sE1Configuration.bAutoRemoteAlarm;
}

unsigned char _stdcall RetE1_nLosSensitivity(void)
{
  return (unsigned char) sE1Configuration.nLosSensitivity;
}

unsigned char _stdcall RetE1_nLosRecovery(void)
{
  return (unsigned char) sE1Configuration.nLosRecovery;
}

unsigned short _stdcall RetE1_nLineLength(void)
{
  return (unsigned short) sE1Configuration.nLineLength;
}

unsigned char _stdcall RetE1_bHighTxPower(void)
{
  return (unsigned char) sE1Configuration.bHighTxPower;
}

unsigned char _stdcall RetE1_bReceiveEqualizer(void)
{
  return (unsigned char) sE1Configuration.bReceiveEqualizer;
}



/* $History: OtxWrapper.c $
 * 
 * *****************  Version 2  *****************
 * User: Steve        Date: 8/24/04    Time: 4:47p
 * Updated in $/Products/OtxWrapper
 * Changed to be compatible with SDK distribution.
 * 
 * *****************  Version 1  *****************
 * User: Steve        Date: 12/30/03   Time: 11:44a
 * Created in $/Products/OtxWrapper
 * Initial revision.
  * 
  *
*/

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2003


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
