/* $Workfile: OtxWrapper.h $   $Revision: 1 $    $Modtime: 12/17/03 4:32p $  */
#ifndef OTX_WRAPPER_H
#define OTX_WRAPPER_H
/*******************************************************************************

  Copyright (C) 1998, 1999 Odin TeleSystems Inc. All Rights Reserved.

  @doc internal

  OTX Telecom Adapter Driver

  @module

  OtxWrapper |

  A simple demonstration wrapper around the OTX SDK library.

*******************************************************************************/

int _stdcall WrapOtxDrvConnectLib(void);
int _stdcall WrapOtxDrvReleaseLib(void);
int _stdcall WrapOtxDrvIteratorBegin(void *pItr);
int _stdcall WrapOtxDrvIteratorEnd(int *pItr);
int _stdcall WrapOtxDrvGetAttributeValueUint32(unsigned int hDevice, unsigned int nAttribId, unsigned int *pAttribValue);
int _stdcall GetOtxDrvGetAttributeValueUint32(unsigned int hDevice, unsigned int nAttribId);
int _stdcall WrapOtxDrvEnumDeviceType(unsigned int hDevice, unsigned int *pItr,unsigned int *peDeviceType);
int _stdcall WrapOtxDrvEnumDevice(unsigned int hDevice, unsigned int eDeviceType, unsigned int *pItr, unsigned int *phChildDevice);
int _stdcall WrapOtxDrvCreateEvent(unsigned int *phEvent);
int _stdcall WrapOtxDrvCreateEventQueue(unsigned int nSize, unsigned int hEvent, unsigned int *phEventQueue);
int _stdcall WrapOtxDrvEnable(unsigned int hObject, unsigned int nTaskRef, unsigned int nWaitMaxMs);
int _stdcall WrapOtxDrvOpenPhysicalDevice(unsigned int hHostDevice, unsigned int eDevType, unsigned int nDevice, unsigned int nEventSourceId, unsigned int hEventQueue, unsigned int *phPhysDevice);
int _stdcall WrapOtxDrvClose(unsigned int hDevice);

int _stdcall WrapOtxE1SetConfiguration(
  unsigned int     hLineDevice,        // Handle to the T1/E1 Transceiver Device
  unsigned int     eTxLineCode,        // Line Coding in Transmit Direction
  unsigned int     eRxLineCode,        // Line Coding in Receive Direction
  unsigned int     eTxFrameFormat,     // Frame Format in Transmit Direction
  unsigned int     eRxFrameFormat,     // Frame Format in Receive Direction
  unsigned int     eAisDetection,      // Alarm Indication Signal (AIS) Detect mode
  unsigned char    bfSiBits,           // E-bit (spare bits for international use) Due to signalling requirements
                                       // the E-bits (SiBits) of frame 13 and frame 15 of the CRC multiframe can be
                                       // used to indicate received errored submultiframes. E-bit of frame 15 is the least
                                       // significant bit (bit 0) of this field. E-bit of frame 13 is bit 1 of this field.
                                       // To set the either E-bit in the in the multiframe
                                       // the corresponding bit position in this field should be turned on.
                                       // E-bit Frame 13, E-bit Frame 15: 00, 01, 10, 11.
                                       // E.g. to set both E-bits (frame 13 and frame 15) set this field to 0x03.
  unsigned char    bfSaBits,           // Set the Sa bits (spare bits for national use) transmitted in bit
                                       // positions 4-8 of time-slot 0 of every other (odd) frame. Use bit pattern
                                       // marking the corresponding bit position '1' the bit should be turned on.
                                       // Sa4, Sa5, Sa6, Sa7, Sa8: 00000, 00001, ..., 11111
                                       // <nl> For all Sa bits on nSaBits = 0x1F
  unsigned char    bExtendedHDB3errorDetect,  // Selects the error detection mode. When turned off (OTX_FALSE),
                                       // only double violations are detected. When turned on (OTX_TRUE), 0000 strings
                                       // are detected as code violations as well.
  unsigned char    bAutoRegainMultiframe,// When enabled (OTX_TRUE), the receiver will search a new basic-
                                       // and multiframing if more than 914 CRC errors have been detected in a
                                       // time interval of one second.
  unsigned char    bAutoResync,        // If OTX_TRUE, the Framer will automatically re-synchronize after
                                       // loss of synchronization. If OTX_FALSE the Framer will not synchronize
                                       // automatically but a re-synchronization procedure must be specifically
                                       // initiated by the software.
  unsigned char    bAutoCrcBitInversion, // If OTX_TRUE, all CRC bits of one outgoing sub-multiframe are
                                       // inverted in case a CRC error is flagged for the previous received 
                                       // sub-multiframe.
  unsigned char    bAutoRemoteAlarm,   // If OTX_TRUE, a Remote Alarm (Yellow Alarm) will be sent automatically
                                       // in the outgoing data stream when the receiver is out of synchronization.
                                       // The alarm will also be automatically removed when the receiver returns to
                                       // the synchronized state.
  unsigned char    nLosSensitivity,    // Sets the sensitivity level for the Loss Of Signal (LOS) detection.
                                       // A LOS alarm will be generated if the incoming data stream has no
                                       // transitions during programmable number (N) of consecutive pulse periods.
                                       // The number given as the LOS Sensitivity value will be multiplied by 16 to
                                       // arrive to the pulse count number N. The time for detecting LOS will be
                                       // 16 x LOS Sensitivity x Pulse Length (488ns).
                                       // The maximum time is 16 x 256 x 488ns = 2ms
                                       // <nl> Possible Values: 1-256
                                       // <nl> Example/Default Value:
                                       // LOS Sensitivity  =  128     (16 x 128 x 488ns = 1ms)
  unsigned char    nLosRecovery,       // Sets the sensitivity level for the Loss Of Signal (LOS) recovery.
                                       // A LOS alarm will be cleared if in the incoming data a number of Pulses (N)
                                       // occur during the time period set with the LOS Recovery parameter. The time
                                       // interval starts with the first detected pulse transition and a pulse
                                       // count is incremented with every received pulse. If the pulse number is
                                       // greater than the number N set with this parameter, the LOS alarm will be cleared.
                                       // <nl> Possible Values: 1-256
  unsigned short   nLineLength,        // Specify the length of the T1 line cable in meters. This information
                                       // is used by the T1 transceivers to adjust the transmit pulse masks according
                                       // to the line length.
                                       // <nl> Possible Values: 0-65535
  unsigned char    bHighTxPower,       // When OTX_TRUE the pulses on the line interface will be sent with
                                       // high power. If OTX_FALSE the pulses will be sent with low power.
  unsigned char    bReceiveEqualizer   // The Receive Equalizer can be used match the 18dB ITU-T I.431
                                       // requirement. When the Equalizer is turned off (OTX_FALSE), the Receiver is -10dB (short haul), when
                                       // turned on (OTX_TRUE), the Receiver is -36dB (long haul).
);

int _stdcall WrapOtxE1GetConfiguration(
  unsigned int     hLineDevice,        // Handle to the T1/E1 Transceiver Device
  unsigned int *  eTxLineeCode,       // Linee CodOUTg OUT Transmit Direction
  unsigned int *  eRxLineeCode,       // Linee CodOUTg OUT Receive Direction
  unsigned int *  eTxFrameFormat,     // Frame Format OUT Transmit Direction
  unsigned int *  eRxFrameFormat,     // Frame Format OUT Receive Direction
  unsigned int *  eAisDetection,      // Alarm OUTdication Signal (AIS) Detect mode
  unsigned char * bfSiBits,           // E-bit (spare bits for OUTternational use) Due to signallOUTg requirements
                                      // the E-bits (SiBits) of frame 13 and frame 15 of the CRC multiframe can be
                                      // used to OUTdicate received errored submultiframes. E-bit of frame 15 is the least
                                      // significant bit (bit 0) of this field. E-bit of frame 13 is bit 1 of this field.
                                      // To set the either E-bit OUT the OUT the multiframe
                                      // the correspondOUTg bit position OUT this field should be turned on.
                                      // E-bit Frame 13, E-bit Frame 15: 00, 01, 10, 11.
                                      // E.g. to set both E-bits (frame 13 and frame 15) set this field to 0x03.
  unsigned char *    bfSaBits,        // Set the Sa bits (spare bits for national use) transmitted OUT bit
                                      // positions 4-8 of time-slot 0 of every other (odd) frame. Use bit pattern
                                      // markOUTg the correspondOUTg bit position '1' the bit should be turned on.
                                      // Sa4, Sa5, Sa6, Sa7, Sa8: 00000, 00001, ..., 11111
                                      // <nl> For all Sa bits on nSaBits = 0x1F
  unsigned char *  bExtendedHDB3errorDetect,  // Selects the error detection mode. When turned off (OTX_FALSE),
                                      // only double violations are detected. When turned on (OTX_TRUE), 0000 strOUTgs
                                      // are detected as code violations as well.
  unsigned char *  bAutoRegainMultiframe,// When enabled (OTX_TRUE), the receiver will search a new basic-
                                      // and multiframOUTg if more than 914 CRC errors have been detected OUT a
                                      // time OUTterval of one second.
  unsigned char *  bAutoResync,       // If OTX_TRUE, the Framer will automatically re-synchronize after
                                      // loss of synchronization. If OTX_FALSE the Framer will not synchronize
                                      // automatically but a re-synchronization procedure must be specifically
                                      // OUTitiated by the software.
  unsigned char *  bAutoCrcBitInversion, // If OTX_TRUE, all CRC bits of one outgoOUTg sub-multiframe are
                                      // OUTverted OUT case a CRC error is flagged for the previous received 
                                      // sub-multiframe.
  unsigned char *  bAutoRemoteAlarm,  // If OTX_TRUE, a Remote Alarm (Yellow Alarm) will be sent automatically
                                      // OUT the outgoOUTg data stream when the receiver is out of synchronization.
                                      // The alarm will also be automatically removed when the receiver returns to
                                      // the synchronized state.
  unsigned char *  nLosSensitivity,   // Sets the sensitivity level for the Loss Of Signal (LOS) detection.
                                      // A LOS alarm will be generated if the OUTcomOUTg data stream has no
                                      // transitions durOUTg programmable number (N) of consecutive pulse periods.
                                      // The number given as the LOS Sensitivity value will be multiplied by 16 to
                                      // arrive to the pulse count number N. The time for detectOUTg LOS will be
                                      // 16 x LOS Sensitivity x Pulse Length (488ns).
                                      // The maximum time is 16 x 256 x 488ns = 2ms
                                      // <nl> Possible Values: 1-256
                                      // <nl> Example/Default Value:
                                      // LOS Sensitivity  =  128     (16 x 128 x 488ns = 1ms)
  unsigned char *  nLosRecovery,      // Sets the sensitivity level for the Loss Of Signal (LOS) recovery.
                                      // A LOS alarm will be cleared if OUT the OUTcomOUTg data a number of Pulses (N)
                                      // occur durOUTg the time period set with the LOS Recovery parameter. The time
                                      // OUTterval starts with the first detected pulse transition and a pulse
                                      // count is OUTcremented with every received pulse. If the pulse number is
                                      // greater than the number N set with this parameter, the LOS alarm will be cleared.
                                      // <nl> Possible Values: 1-256
  unsigned short * nLineeLength,      // Specify the length of the T1 lOUTe cable OUT meters. This OUTformation
                                      // is used by the T1 transceivers to adjust the transmit pulse masks accordOUTg
                                      // to the lOUTe length.
                                      // <nl> Possible Values: 0-65535
  unsigned char *  bHighTxPower,      // When OTX_TRUE the pulses on the lOUTe OUTterface will be sent with
                                      // high power. If OTX_FALSE the pulses will be sent with low power.
  unsigned char *  bReceiveEqualizer  // The Receive Equalizer can be used match the 18dB ITU-T I.431
                                      // requirement. When the Equalizer is turned off (OTX_FALSE), the Receiver is -10dB (short haul), when
                                      // turned on (OTX_TRUE), the Receiver is -36dB (long haul).
);

int _stdcall SetE1Configuration(unsigned int hLineDevice);
void _stdcall SetE1_eTxLineCode(unsigned int eTxLineCode);
void _stdcall SetE1_eRxLineCode(unsigned int eRxLineCode);
void _stdcall SetE1_eTxFrameFormat(unsigned int eTxFrameFormat);
void _stdcall SetE1_eRxFrameFormat(unsigned int eRxFrameFormat);
void _stdcall SetE1_eAisDetection(unsigned int eAisDetection);
void _stdcall SetE1_bfSiBits(unsigned char bfSiBits);
void _stdcall SetE1_bfSaBits(unsigned char bfSaBits);
void _stdcall SetE1_bExtendedHDB3errorDetect(unsigned char bExtendedHDB3errorDetect);
void _stdcall SetE1_bAutoRegainMultiframe(unsigned char bAutoRegainMultiframe);
void _stdcall SetE1_bAutoResync(unsigned char bAutoResync);
void _stdcall SetE1_bAutoCrcBitInversion(unsigned char bAutoCrcBitInversion);
void _stdcall SetE1_bAutoRemoteAlarm(unsigned char bAutoRemoteAlarm);
void _stdcall SetE1_nLosSensitivity(unsigned char nLosSensitivity);
void _stdcall SetE1_nLosRecovery(unsigned char nLosRecovery);
void _stdcall SetE1_nLineLength(unsigned short nLineLength);
void _stdcall SetE1_bHighTxPower(unsigned char bHighTxPower);
void _stdcall SetE1_bReceiveEqualizer(unsigned char bReceiveEqualizer);
int _stdcall GetE1Configuration(unsigned int hLineDevice);
int _stdcall GetE1_eTxLineCode(unsigned int *eTxLineCode);
int _stdcall GetE1_eRxLineCode(unsigned int *eRxLineCode);
int _stdcall GetE1_eTxFrameFormat(unsigned int *eTxFrameFormat);
int _stdcall GetE1_eRxFrameFormat(unsigned int *eRxFrameFormat);
int _stdcall GetE1_eAisDetection(unsigned int *eAisDetection);
int _stdcall GetE1_bfSiBits(unsigned char *bfSiBits);
int _stdcall GetE1_bfSaBits(unsigned char *bfSaBits);
int _stdcall GetE1_bExtendedHDB3errorDetect(unsigned char *bExtendedHDB3errorDetect);
int _stdcall GetE1_bAutoRegainMultiframe(unsigned char *bAutoRegainMultiframe);
int _stdcall GetE1_bAutoResync(unsigned char *bAutoResync);
int _stdcall GetE1_bAutoCrcBitInversion(unsigned char *bAutoCrcBitInversion);
int _stdcall GetE1_bAutoRemoteAlarm(unsigned char *bAutoRemoteAlarm);
int _stdcall GetE1_nLosSensitivity(unsigned char *nLosSensitivity);
int _stdcall GetE1_nLosRecovery(unsigned char *nLosRecovery);
int _stdcall GetE1_nLineLength(unsigned short *nLineLength);
int _stdcall GetE1_bHighTxPower(unsigned char *bHighTxPower);
int _stdcall GetE1_bReceiveEqualizer(unsigned char *bReceiveEqualizer);
unsigned int _stdcall RetE1_eTxLineCode(void);
unsigned int _stdcall RetE1_eRxLineCode(void);
unsigned int _stdcall RetE1_eTxFrameFormat(void);
unsigned int _stdcall RetE1_eRxFrameFormat(void);
unsigned int _stdcall RetE1_eAisDetection(void);
unsigned char _stdcall RetE1_bfSiBits(void);
unsigned char _stdcall RetE1_bfSaBits(void);
unsigned char _stdcall RetE1_bExtendedHDB3errorDetect(void);
unsigned char _stdcall RetE1_bAutoRegainMultiframe(void);
unsigned char _stdcall RetE1_bAutoResync(void);
unsigned char _stdcall RetE1_bAutoCrcBitInversion(void);
unsigned char _stdcall RetE1_bAutoRemoteAlarm(void);
unsigned char _stdcall RetE1_nLosSensitivity(void);
unsigned char _stdcall RetE1_nLosRecovery(void);
unsigned short _stdcall RetE1_nLineLength(void);
unsigned char _stdcall RetE1_bHighTxPower(void);
unsigned char _stdcall RetE1_bReceiveEqualizer(void);


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif  // OTX_WRAPPER_H
